const mongoose = require("mongoose");

const OrdersSchema = new mongoose.Schema(
  {
    "customer-id": Object,
    amount: {
      type: Number,
    },
    "shipping-address": {
      type: Object,
    },
    phone: {
      type: String,
    },
    status: {
      type: String,
      enum: ["Processing", "Packing", "Shipping", "Delivered"],
      default: "Processing",
    },
    notes: String,
    "payment-method": {
      type: String,
      default: "Cash on delivery",
    },
    cart: {
      type: [
        {
          id: {
            type: String,
            required: true,
          },
          title: {
            type: String,
            required: true,
          },
          thumbnail: {
            type: String,
            required: true,
          },
          price: {
            type: Number,
            required: true,
          },
          discount: {
            type: Number,
            required: true,
          },
          size: {
            type: String,
            required: true,
          },
          color: {
            type: String,
            required: true,
          },
          count: {
            type: Number,
            required: true,
          },
          slug: {
            type: String,
            required: true,
          },
        },
      ],
      required: true,
    },
  },
  { required: ["cart", "customer-id", "shipping-address"] },
  { timestamps: true }
);

const OrdersModule = mongoose.model("Order", OrdersSchema);

module.exports = OrdersModule;
